#
# spec file for package tachyon
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tachyon
%define lname	libtachyon-0_99_5
Version:        0.99.5
Release:        1.9
Summary:        Parallel ray tracing system
License:        BSD-3-Clause
Group:          Productivity/Graphics/Visualization/Raytracers
URL:            http://jedi.ks.uiuc.edu/~johns/raytracer/

Source:         http://jedi.ks.uiuc.edu/~johns/raytracer/files/%version/tachyon-%version.tar.gz
Patch1:         tachyon-automake.diff
BuildRequires:  autoconf
BuildRequires:  automake >= 1.10
BuildRequires:  libjpeg-devel
BuildRequires:  libtool >= 2
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(x11)

%description
A parallel ray tracing system supporting MPI and multithreaded
implementations.

Tachyon implements the basic geometric primitives such as triangles,
planes, spheres, cylinders, etc. Tachyon parallelizes unlike POV-Ray
and Rayshade.

%package -n %lname
Summary:        Core library for the Tachyon Parallel Ray Tracing System
Group:          System/Libraries

%description -n %lname
A parallel ray tracing system supporting MPI and multithreaded
implementations.

Tachyon implements the basic geometric primitives such as triangles,
planes, spheres, cylinders, etc. Tachyon parallelizes unlike POV-Ray
and Rayshade.

%package devel
Summary:        Development files for the Tachyon Ray Tracing System
Group:          Development/Libraries/C and C++
Requires:       %lname = %version-%release
Obsoletes:      libtachyon-devel < %version-%release
Provides:       libtachyon-devel = %version-%release

%description devel
A parallel ray tracing system supporting MPI and multithreaded
implementations.

This package contains the headers for the Tachyon library.

%prep
%autosetup -p1 -n %name

%build
autoreconf -fi
%configure --disable-static
%make_build

%install
b="%buildroot"
mkdir -p "$b/%_includedir/tachyon"
for i in tachyon.h tachyon_dep.h hash.h macros.h render.h quadric.h texture.h light.h util.h; do
	install -pm 0644 "src/$i" "$b/%_includedir/tachyon/$i"
done
%make_install
rm -f "$b/%_libdir"/*.la

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files
%_bindir/tachyon
%license Copyright

%files -n %lname
%_libdir/libtachyon-*.so

%files devel
%_libdir/libtachyon.so
%_includedir/tachyon/

%changelog
* Wed Aug 10 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.99.5
  * Implemented a new higher performance octahedron normal vector
    decoding variant that eliminates GPU SIMD divergence and
    costs fewer instructions
  * Added a completely flattened closest-hit dispatch approach
    through bitwise manipulation of the outpus of the OptiX 7
    optixGetHitKind() and optixGetPrimitiveType() APIs.
  * Added SBT-local hitgroup geometry flags containing
    cached/flattened material opacity, texture alpha cutout, and
    other information useful for short-circuiting frequent high
    latency data fetches from global memory or textures,
    particularly those items needed for for any-hit programs.
* Thu Apr 21 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.99.4
  * Added support for AO maximum occlusion distance cutoff, for
    convenient rendering of interior scenes where the "sky" would
    otherwise be largely or fully occluded.
  * Updated grid acceleration structure generation logic to avoid
    integer wraparound when working with scenes containing
    billions of objects and very large resulting grids.
  * Added a rough draft implementation of a quadrilateral mesh
    primitive
  * Migrated gradient noise magnitude and associated calculations
    outside of the ray tracing kernels themselves.
  * Unified the various camera raygen program alpha transparency
    code.
  * Added mainstream tone mapping operators and corrected alpha
    channel handling in colorspace conversions.
* Thu Dec 24 2020 Jan Engelhardt <jengelh@inai.de>
- Specfile modernizations. Remove conjecture from descriptions.
* Thu Feb  8 2018 jengelh@inai.de
- Remove old SLES BuildRequires.
* Wed Feb  5 2014 jengelh@inai.de
- Update to new upstream release 0.99~b6
  * a new barrier synchronization mechanism was implemented for
  synchronizing the pool of worker threads on each node prior to
  sending/receiving the image buffer via MPI.
  * Added support for atomic integer ops for improved performance
  when mixing threads and distributed memory message passing.
* Thu Dec 13 2012 jengelh@inai.de
- Install the tachyon main program
* Sun Apr 22 2012 alinm.elena@gmail.com
- added *.h in the devel packages... I hope I added all
  I have managed to build vmd from cvs with them
* Tue Sep 27 2011 jengelh@medozas.de
- Initial package (version 0.99_b2) for build.opensuse.org
